/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2015.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#ifndef __FWRUNTIME_DL_NAMESPACE_HPP__
#define __FWRUNTIME_DL_NAMESPACE_HPP__


namespace fwRuntime
{
/**
 * @brief       The namespace fwRuntime::dl contains classes to manage library module.
 * @namespace   fwRuntime::dl
 *
 * @date        2009-2010.
 *
 */
namespace dl
{

}
}
#endif /* __FWRUNTIME_DL_NAMESPACE_HPP__ */
